pub type BookmarkTarget = CausalBookmark;Expand description
Backwards-compatible client name for the wire causal bookmark token.
Aliased Type
pub struct BookmarkTarget { /* private fields */ }pub type BookmarkTarget = CausalBookmark;Backwards-compatible client name for the wire causal bookmark token.
pub struct BookmarkTarget { /* private fields */ }