Module error

Module error 

Error type for reddb-client.

Mirrors the JSON-RPC error codes used by red rpc --stdio so that client error mapping is consistent across all language drivers. See PLAN_DRIVERS.md  “Spec do protocolo stdio”.

Structs

ClientError
Error returned by every fallible call in this crate.

Enums

ErrorCode
Stable, machine-readable error code.

Type Aliases

Result
Result alias for the entire crate.